<?php
    use App\Enums\SchemePayout as SPayout;
    use App\Enums\InterestPeriod as IPeriod;
    use App\Enums\SchemeTermTypes as STType;
    use App\Enums\InterestRateType as IRType;
    use App\Enums\SchemeStatus as SStatus;

    $uid = (!blank($scheme)) ? the_hash($scheme->id) : request()->get('uid');

    if ($type=='new' && has_route('admin.investment.scheme.save')) {
        $form_action = route('admin.investment.scheme.save');
    } else {
        $form_action = route('admin.investment.scheme.update', ['id' => $uid]);
    }
?>

<div class="modal-dialog modal-dialog-centered modal-lg" role="document">
    <div class="modal-content">
        <a href="#" class="close" data-dismiss="modal"><em class="icon ni ni-cross-sm"></em></a>
        <div class="modal-body modal-body-md">
            <h5 class="title nk-modal-title"><?php echo e(__(':Type Scheme / Plan', ['type' => $type])); ?></h5>
            <form action="<?php echo e($form_action); ?>" class="form-validate is-alter"<?php echo ($type!='new') ? ' data-confirm="update"' : ''; ?>>
                <div class="row gy-2">
                    <div class="col-md-8">
                        <div class="form-group">
                            <label class="form-label" for="scheme-name"><?php echo e(__('Scheme Name')); ?></label>
                            <div class="form-control-wrap">
                                <input type="text" name="name" class="form-control" id="scheme-name" value="<?php echo e(data_get($scheme, 'name', '')); ?>" required>
                            </div>
                            <div class="form-note"><?php echo e(__("The name of investment scheme.")); ?></div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="form-label" for="shortcode"><?php echo e(__('Short Name')); ?></label>
                            <div class="form-control-wrap">
                                <input type="text" name="short" class="form-control" id="shortcode" maxlength="2" value="<?php echo e(data_get($scheme, 'short', '')); ?>" required>
                            </div>
                            <div class="form-note"><?php echo e(__("The short name for plan.")); ?></div>
                        </div>
                    </div>
                    <div class="col-md-12">
                        <div class="form-group">
                            <label class="form-label" for="scheme-desc"><?php echo e(__('Scheme Description')); ?></label>
                            <div class="form-control-wrap">
                                <input type="text" name="desc" class="form-control" id="scheme-desc" value="<?php echo e(data_get($scheme, 'desc', '')); ?>">
                            </div>
                        </div>
                    </div>
                </div>
                <div class="divider md mb-3 stretched"></div>
                <div class="row gy-3">
                    <div class="col-lg-6">
                        <div class="form-group">
                            <label class="form-label" for="invest-amount"><?php echo e(__('Investment Amount')); ?></label>
                            <div class="row g-2">
                                <div class="col-6">
                                    <div class="form-control-wrap">
                                        <input type="text" name="amount" class="form-control" id="invest-amount" min="0.001" data-msg-min="<?php echo e(__("More than 0.001")); ?>" value="<?php echo e(data_get($scheme, 'amount')); ?>" required>
                                    </div>
                                    <div class="form-note"><?php echo e(__('Minimum (:currency)', ['currency' => base_currency()])); ?></div>
                                </div>
                                <div class="col-6">
                                    <div class="form-control-wrap">
                                        <input type="text" name="maximum" class="form-control" id="invest-maximum" value="<?php echo e(data_get($scheme, 'maximum')); ?>">
                                    </div>
                                    <div class="form-note"><?php echo e(__('Maximum (:currency)', ['currency' => base_currency()])); ?></div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="form-group">
                            <label class="form-label" for="interest-rate"><?php echo e(__('Interest Rate / Profit')); ?></label>
                            <div class="row g-2">
                                <div class="col-6">
                                    <div class="form-control-wrap">
                                        <input name="rate" type="text" class="form-control" id="interest-rate" value="<?php echo e(data_get($scheme, 'rate')); ?>" required>
                                    </div>
                                    <div class="form-note"><?php echo e(__('Amount')); ?></div>
                                </div>
                                <div class="col-6">
                                    <div class="form-control-wrap">
                                        <select name="types" class="form-select form-control">
                                            <?php $__currentLoopData = get_enums(IRType::class, false); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $term): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                                <option<?php echo e((data_get($scheme, 'rate_type') == $term) ? ' selected' : ''); ?> value="<?php echo e($term); ?>"><?php echo e(ucfirst($term)); ?></option>
                                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                        </select>
                                    </div>
                                    <div class="form-note"><?php echo e(__('Interest Type')); ?></div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-6 col-lg-3">
                        <label class="form-label" for="interest-period"><?php echo e(__('Interest Period')); ?></label>
                        <div class="form-control-wrap">
                            <select name="period" class="form-select form-control" id="interest-period">
                                <?php $__currentLoopData = get_enums(IPeriod::class, false); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $term): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <option<?php echo e((data_get($scheme, 'calc_period') == $term) ? ' selected' : ''); ?> value="<?php echo e($term); ?>"><?php echo e(ucfirst($term)); ?></option>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </select>
                        </div>
                    </div>
                    <div class="col-6 col-lg-3">
                        <div class="form-group">
                            <label class="form-label" for="payout-policy"><?php echo e(__('Payout Term')); ?></label>
                            <div class="form-control-wrap">
                                <select name="payout" class="form-select form-control" id="payout-policy" required>
                                    <?php $__currentLoopData = get_enums(SPayout::class, false); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $term): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                        <option<?php echo e((data_get($scheme, 'payout') == $term) ? ' selected' : ''); ?><?php echo e(($term == 'after_matured') ? ' disabled' : ''); ?> value="<?php echo e($term); ?>"><?php echo e(str_replace('_', ' ', ucfirst($term))); ?></option>
                                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group">
                            <label class="form-label" for="term-duration"><?php echo e(__('Term Duration')); ?></label>
                            <div class="row g-2">
                                <div class="col-6">
                                    <input type="text" name="term" class="form-control" id="term-duration" value="<?php echo e(data_get($scheme, 'term')); ?>" required>
                                </div>
                                <div class="col-6">
                                    <select name="duration" class="form-select form-control" required>
                                        <?php $__currentLoopData = get_enums(STType::class, false); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $term): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                            <option <?php if(data_get($scheme, 'term_type') == $term): ?> selected <?php endif; ?> value="<?php echo e($term); ?>"><?php echo e(ucfirst($term)); ?></option>
                                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="divider md mb-3 stretched"></div>
                <div class="row gy-3">
                    <div class="col-12">
                        <div class="row gy-1">
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <div class="form-control-wrap mb-1">
                                        <div class="custom-control custom-control-labeled custom-switch">
                                            <input name="fixed" type="checkbox" class="custom-control-input" id="is-fixed-amount"<?php echo e((data_get($scheme, 'is_fixed')) ? ' checked=""' : ''); ?>>
                                            <label class="custom-control-label" for="is-fixed-amount"><?php echo e(__('Set as Fixed Type investment.')); ?></label>
                                        </div>
                                    </div>
                                    <div class="form-control-wrap mb-1">
                                        <div class="custom-control custom-control-labeled custom-switch">
                                            <input name="capital" type="checkbox" class="custom-control-input" id="capital-return"<?php echo e((data_get($scheme, 'capital', 1)) ? ' checked=""' : ''); ?>>
                                            <label class="custom-control-label" for="capital-return"><?php echo e(__('Return capital at end of the term.')); ?></label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <div class="form-control-wrap">
                                        <div class="custom-control custom-control-labeled custom-switch">
                                            <input name="featured" type="checkbox" class="custom-control-input" id="is-featured"<?php echo e((data_get($scheme, 'featured')) ? ' checked=""' : ''); ?>>
                                            <label class="custom-control-label" for="is-featured"><?php echo e(__('Set as Featured plan.')); ?></label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php if($type!='new'): ?>
                        <div class="notes mt-4">
                            <ul>
                                <li class="alert-note is-plain text-danger">
                                    <em class="icon ni ni-alert"></em>
                                    <p><strong><?php echo e(__('Notes:')); ?></strong> <?php echo e(__('Your changes does not affect on old subscription as only affect to new subscription.')); ?></p>
                                </li>
                            </ul>
                        </div>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="divider md stretched"></div>
                <div class="row">
                    <div class="col-12">
                        <div class="align-center flex-nowrap g-3">
                            <div class="col">
                                <div class="custom-control custom-switch">
                                    <input name="status" id="plan-status" type="checkbox" class="custom-control-input"<?php echo e((data_get($scheme, 'status', SStatus::INACTIVE) == SStatus::ACTIVE) ? ' checked=""' : ''); ?>>
                                    <label for="plan-status" class="custom-control-label"><?php echo e(__('Active')); ?></label>
                                </div>
                            </div>
                            <div class="col">
                                <ul class="align-center justify-content-end flex-nowrap gx-4">
                                    <li class="order-last">
                                        <?php if(data_get($scheme, 'id')): ?>
                                            <input name="id" type="hidden" value="<?php echo e(data_get($scheme, 'id')); ?>">
                                        <?php endif; ?>
                                        <button type="button" class="btn btn-primary m-ivs-save" data-action="update">
                                            <span class="spinner-border spinner-border-sm hide" role="status" aria-hidden="true"></span>
                                            <span><?php echo e((($type=='new') ? __('Add Scheme') : __('Save Scheme'))); ?></span>
                                        </button>
                                    </li>
                                    <li class="d-none d-sm-inline">
                                        <a href="#" data-dismiss="modal" class="link link-danger"><?php echo e(__('Cancel')); ?></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>
<?php /**PATH /home/daulccuo/public_html/frontpage/core_invapp/resources/views/investment/admin/schemes/form.blade.php ENDPATH**/ ?>